﻿using System;
using System.Diagnostics;
using System.Windows;
using FilteringXamGrid.Models;
using FilteringXamGrid.ViewModels;
using Infragistics;
using Infragistics.Controls.Grids;

namespace FilteringXamGrid
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
           
            this.DataContext = new UrlViewModel();
           
        }

        private void Hyperlink_RequestNavigate(object sender, System.Windows.Navigation.RequestNavigateEventArgs e)
        {
            Process.Start(new ProcessStartInfo(e.Uri.AbsoluteUri));
            e.Handled = true;
        }

        private void XamGrid_Loaded(object sender, RoutedEventArgs e)
        {
            (sender as XamGrid).Columns.DataColumns["Section"].FilterColumnSettings.RowFilterOperands.Add(new NullFilterOperand<Url>() { });
            (sender as XamGrid).Columns.DataColumns["Section"].FilterColumnSettings.RowFilterOperands.Add(new NotNullFilterOperand<Url>() { });
        }

    }

    public class NullFilterOperand : FilterOperand
    {
        protected override string DefaultDisplayName
        {
            get
            {
                return "Blanks";
            }
        }

        public override bool RequiresFilteringInput
        {
            get
            {
                return false;
            }
        }
    }

    public class NotNullFilterOperand : FilterOperand
    {
        protected override string DefaultDisplayName
        {
            get
            {
                return "Not Blanks";
            }
        }

        public override bool RequiresFilteringInput
        {
            get
            {
                return false;
            }
        }
    }

    public class NullFilterOperand<T> : NullFilterOperand
    {
        public override System.Linq.Expressions.Expression FilteringExpression(object value)
        {
            MyFilterContext<T> filterContext = new MyFilterContext<T>();

            System.Linq.Expressions.Expression expr = filterContext.MakeAStringEmptyExpression("SectionName", null);

            return expr;
        }
    }

    public class NotNullFilterOperand<T> : NotNullFilterOperand
    {
        public override System.Linq.Expressions.Expression FilteringExpression(object value)
        {
            MyFilterContext<T> filterContext = new MyFilterContext<T>();

            System.Linq.Expressions.Expression expr = filterContext.MakeAStringNotEmptyExpression("SectionName", null);

            return expr;
        }
    }

    public class MyFilterContext<T> : FilterContext<T>
    {
        public MyFilterContext() : base(typeof(string), false, false, new CachedTypedInfo())
        {

        }

        public System.Linq.Expressions.Expression<Func<T, bool>>
                    MakeAStringEmptyExpression(string fieldName, string value)
        {
            return this.CreateStringEmptyExpression<T>(fieldName, value);
        }

        public System.Linq.Expressions.Expression<Func<T, bool>> 
                      MakeAStringNotEmptyExpression(string fieldName, string value)
        {
            return this.CreateStringNotEmptyExpression<T>(fieldName, value);
        }
    }

}
